@@ -49,6 +49,10 @@ private slots:
 public:
 private:
 	QLabel *ausearchLabel;
+	QLabel *startdayLabel;
+	QLabel *starttimeLabel;
+	QLabel *enddayLabel;
+	QLabel *endtimeLabel;
 	QButton *ausearchButton;
 	QButtonGroup *optionButtonGroup;
         QRadioButton *eventRadioButton;
@@ -69,6 +73,10 @@ private:
 	QCheckBox *interpretCheckBox;
 
 	QLineEdit *ausearchEditLineEdit;
+	QLineEdit *startdayEditLineEdit;
+	QLineEdit *starttimeEditLineEdit;
+	QLineEdit *enddayEditLineEdit;
+	QLineEdit *endtimeEditLineEdit;
 	QString ausearchEditLineEdit_str;
 	QPushButton *closeButton;
 	QTextEdit *textEdit1;
@@ -77,12 +85,18 @@ private:
 	QHBoxLayout *firstLayout;
 	QVBoxLayout *secondLayout;
 	QVBoxLayout *thirdLayout;
+	QHBoxLayout *tirsharyLayout;
+	QHBoxLayout *quadroLayout;
 	QHBoxLayout *fourthLayout;
 	QVBoxLayout *middleLayout;
 	QHBoxLayout *footLayout;
 
         QString ausearch_str_pp;
         QString ausearch_str_pp_str;
+	QString startdayEditLineEdit_str;
+	QString starttimeEditLineEdit_str;
+	QString enddayEditLineEdit_str;
+	QString endtimeEditLineEdit_str;
 };
 
 #endif
