@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,30 +44,7 @@ SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDi
 {
 	setCaption(tr("Semanage Process"));
 	textEdit1 = new QTextEdit(this);
-	textEdit1->setPaletteBackgroundColor(QColor(0,254,100));
-/*
-	textEdit2 = new QTextEdit(this);
-	textEdit2->setPaletteBackgroundColor(QColor(0,100,200));
-	textEdit3 = new QTextEdit(this);
-	textEdit3->setPaletteBackgroundColor(QColor(200,100,255));
-	semanageEditLabel = new QLabel(tr("Copy and paste module name:"), this );
-	semanageEditLineEdit = new QLineEdit( this );
-	semanageEditLineEdit->setText("");
-	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
-
-	makeButton = new QPushButton(tr("Make this module"), this);
-	makeButton->setPaletteBackgroundColor(QColor(20,157,20));
-	connect(makeButton, SIGNAL(clicked()), this, SLOT(make_button_clicked()));
-	installButton = new QPushButton(tr("Install this module"), this);
-	installButton->setPaletteBackgroundColor(QColor(220,120,120));
-	connect(installButton, SIGNAL(clicked()), this, SLOT(install_button_clicked()));
-	updateButton = new QPushButton(tr("Update this module"), this);
-	updateButton->setPaletteBackgroundColor(QColor(120,220,120));
-	connect(updateButton, SIGNAL(clicked()), this, SLOT(update_button_clicked()));
-	removeButton = new QPushButton(tr("Remove this module"), this);
-	removeButton->setPaletteBackgroundColor(QColor(155,155,155));
-	connect(removeButton, SIGNAL(clicked()), this, SLOT(remove_button_clicked()));
-*/
+	textEdit1->setPaletteBackgroundColor(QColor(200,254,100));
 	closeButton = new QPushButton(tr("close"), this);
 	//closing process button
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
@@ -82,30 +59,9 @@ SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDi
 	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-/*
-	underLayout = new QVBoxLayout;
-	underLayout->addWidget(textEdit2);
-	leftLayout = new QHBoxLayout;
-	leftLayout->addWidget(textEdit3);
-	leftLayout->addStretch(2);
-	leftLayout->addWidget(semanageEditLabel);
-	leftLayout->addWidget(semanageEditLineEdit);
-	leftLayout->addStretch(5);
-
-	rightLayout = new QHBoxLayout;
-	rightLayout->addWidget(makeButton);
-	rightLayout->addWidget(installButton);
-	rightLayout->addWidget(updateButton);
-	rightLayout->addWidget(removeButton);
-*/
-
 	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
-/*
-	underLayout->addLayout(leftLayout);
-	underLayout->addLayout(rightLayout);
-*/
 
 	mainLayout->addLayout(upperLayout);
 	//mainLayout->addLayout(underLayout);
@@ -508,9 +464,6 @@ void SemanageCoreProcess::readFromOutputFile()
 			if ( file.open( IO_ReadOnly ) ) {
 				QTextStream stream( &file );
 				////////////////////////////////////////////
-				//agroup = new QButtonGroup( this );
-				//button_numbers = 1;
-				//textEdit1->clear();
 				if(order_x == 1)
 					textEdit1->append("#########login list#########");
 					textEdit1->append("");
@@ -534,21 +487,9 @@ void SemanageCoreProcess::readFromOutputFile()
 					textEdit1->append("");
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
-					//buttons.push_back(line_analized);
 					textEdit1->append(line_analized);
-					//radiobutton_obj = line_analized + "RadioButton";
-					//radiobutton_obj = line_analized;
-
-					//radiobutton_objButton = new QRadioButton(tr(radiobutton_obj), agroup);
-					//headLayout->addWidget(radiobutton_objButton);
-
-					//radiobutton_obj = line_analized.section( ' ', 0, 0 );
-					//int i = line_analized.find( QRegExp("^[ \t\n\r\f]+"), 0 );
-					//int i = line_analized.find( QRegExp("[\t]"), 0 );
-					//cout << "i:" << i << endl;
-					//cout << "radiobutton_obj:" << radiobutton_obj << endl;
-					//++button_numbers;
 				}
+				textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
@@ -557,40 +498,3 @@ void SemanageCoreProcess::readFromOutputFile()
 			}
 		}
 }
-//this slot should be called from above slot
-/*
-void SemanageCoreProcess::readFromOutputFile2()
-{
-	/////////////////////////////////////////////////////////////
-	//path = "./";
-	path = "/root/segatex";
-	/////////////////////////////////////////////////////////////
-	forward_slash = "/";
-	dir.setPath(path);
-	dir_name = dir.absPath();
-	/////////////////////////////////////////////////////////////
-	dir.setFilter( QDir::Files );
-        dir.setSorting( QDir::Name );
-	files = dir.entryList(outputfile_str_common2);
-	/////////////////////////////////////////////////////////////
-	it_d = files.begin();
-		while(it_d != files.end()){
-			name = *it_d;
-			file_interface_name = dir_name + forward_slash + name;
-			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
-				////////////////////////////////////////////
-				textEdit2->clear();
-				while ( !stream.atEnd() ) {
-					line_analized = stream.readLine(); // line of text excluding '\n'
-					textEdit2->append(line_analized);
-				}
-				file.close();
-				++it_d;
-			}else{
-				//do nothing
-			}
-		}
-}
-*/
